==> haskell-aeson-better-errors-0.9.1.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-better-errors
version:              0.9.1.3
visibility:           public
id:                   aeson-better-errors-0.9.1.3-6AtDMXIk7EXLnJ5a24ZyeQ
key:                  aeson-better-errors-0.9.1.3-6AtDMXIk7EXLnJ5a24ZyeQ
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  d5099efacbda6b56744a31bb815148d0
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.3-6AtDMXIk7EXLnJ5a24ZyeQ
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1
    bytestring-0.11.5.3 dlist-1.0-BKgPi70fx5AJreCYiKxIIN mtl-2.2.2
    scientific-0.3.8.0-HUqAf4XaF5T5GawpMI5GwR text-2.0.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-better-errors
version:              0.9.1.3
visibility:           public
id:                   aeson-better-errors-0.9.1.3-67c3NzpPf6tHNaO4fyXDAe
key:                  aeson-better-errors-0.9.1.3-67c3NzpPf6tHNaO4fyXDAe
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  68fea36892a11f6fdbacf253a866782a
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.3-67c3NzpPf6tHNaO4fyXDAe
depends:
    aeson-2.1.2.1-4XssoWP8s0tKPHSv4bO4jS base-4.17.2.1
    bytestring-0.11.5.3 dlist-1.0-BKgPi70fx5AJreCYiKxIIN mtl-2.2.2
    scientific-0.3.8.0-7k94WWHeF91KCJJx1troIA text-2.0.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-3371VA61Be1CojVrkG24uM
    vector-0.13.2.0-EWs7nDhBFQF5RfgCWU6KmC
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
